function varargout=configure(varargin)
% FUNCTION fc_simesh.configure()
%   Configures the toolbox/package by setting <fc-oogmsh> and <HyperMesh> toolbox directory.
%   Theses informations will be stored in ... file.
%
% <COPYRIGHT>
  [conffile,isFileExists]=fc_simesh.getLocalConfFile();
  if isFileExists
    run(conffile);
  else
    fullname=mfilename('fullpath');
    I=strfind(fullname,filesep);
    Path=fullname(1:(I(end-1)-1));
    oogmsh_dir='';    % empty if pkg or toolbox in path
    hypermesh_dir=''; % empty if pkg or toolbox in path
    siplt_dir='';
  end
  p = inputParser;
  p.addParamValue('oogmsh_dir'   ,oogmsh_dir,@ischar);
  p.addParamValue('hypermesh_dir',hypermesh_dir,@ischar);
  p.addParamValue('siplt_dir',siplt_dir,@ischar);
  %p.addParamValue('force',false,@islogical); 
  p.parse(varargin{:});
  R=p.Results;
  
  if ~isempty(R.oogmsh_dir) && ~isdir(R.oogmsh_dir), error('Not a directory :\n''oogmsh_dir''=%s\n', R.oogmsh_dir); end
  if ~isempty(R.hypermesh_dir) &&~isdir(R.hypermesh_dir), error('Not a directory :\n''hypermesh_dir''=%s\n', R.hypermesh_dir); end
  if isempty(R.siplt_dir)
    fprintf('[fc-simesh] no graphics package installed\n')
  else
    if ~isdir(R.siplt_dir), error('Not a directory :\n''siplt_dir''=%s\n', R.siplt_dir); end
  end
  
  fprintf('Write in %s ...\n',conffile);
  fid=fopen(conffile,'w');
  if (fid==0), error('Unable to open file :\n %s\n',conffile);end
  fprintf(fid,'%% Automaticaly generated with fc_simesh.configure()\n');
  fprintf(fid,'oogmsh_dir=''%s'';\n',R.oogmsh_dir);
  fprintf(fid,'hypermesh_dir=''%s'';\n',R.hypermesh_dir);
  fprintf(fid,'siplt_dir=''%s'';\n',R.siplt_dir);
  fclose(fid);
  fprintf('  -> done\n');
  if nargout==1,varargout{1}=conffile;end
end